@@ -12,7 +12,8 @@ class ErrorInfo(Error):
     """
 
     code = 105
-    msg: str = 'Use `print() instead of `print("")`'
+    msg: str = 'Replace `print("")` with `print()`'
+    categories = ["builtin", "readability"]
 
 
 def check(node: CallExpr, errors: list[Error]) -> None:
