@@ -34,6 +34,7 @@ class ErrorInfo(Error):
     """
 
     code = 103
+    categories = ["pathlib"]
 
 
 def check(node: WithStmt, errors: list[Error]) -> None:
@@ -63,6 +64,6 @@ def check(node: WithStmt, errors: list[Error]) -> None:
                 ErrorInfo(
                     node.line,
                     node.column,
-                    f"Use `y = Path(x).{func}(y)` instead of `with open(x, ...) as f: f.write(y)`",  # noqa: E501
+                    f"Replace `with open(x, ...) as f: f.write(y)` with `Path(x).{func}(y)`",  # noqa: E501
                 )
             )
